<?php
/**
 * $Horde: mottle/edit.php,v 1.22 2008-01-02 11:13:48 jan Exp $
 *
 * Copyright 2003-2008 The Horde Project (http://www.horde.org/)
 *
 * See the enclosed file LICENSE for license information (BSD). If you
 * did not receive this file, see http://www.horde.org/licenses/bsdl.php.
 *
 * @author  Eric Jon Rostetter <eric.rostetter@physics.utexas.edu>
 * @author  Daniel Vandal <dvandal@infoteck.qc.ca>
 * @package Mottle
 */

@define('MOTTLE_BASE', dirname(__FILE__));
require_once MOTTLE_BASE . '/lib/base.php';
require_once 'Horde/Form.php';
require_once 'Horde/Form/Action.php';
require_once 'Horde/Form/Renderer.php';
require_once 'Horde/Variables.php';

/* Only admins should be using this. */
if (!Auth::isAdmin()) {
    $notification->push(_("You are not authorised for this action."), 'horde.warning');
    Horde::authenticationFailureRedirect();
}

/* Get some variables. */
$vars = Variables::getDefaultVariables();

/* Set up the form object. */
$form = new Horde_Form($vars);
$form->addHidden('', 'motd_id', 'text', false);
$form->addHidden('', 'rtemode', 'boolean', false);
$form->addHidden('', 'change_rtemode', 'boolean', false);
$form->addVariable(_("Title"), 'motd_title', 'text', true);
$form->addVariable(_("Post time"), 'motd_post_time', 'monthdayyear', true);
$form->addVariable(_("Expire time"), 'motd_expire_time', 'monthdayyear', true);

/* Determine the composition type - text or HTML according to the
 * configuration file of Mottle and if the browser supports this
 * feature */
if ($browser->hasFeature('rte') && $conf['compose']['html']) {
    $form->addVariable(_("Text"), 'motd_text', 'longtext', true, false, null, array(8, 80, array('rte')));
} else {
    $form->addVariable(_("Text"), 'motd_text', 'longtext', true);
}

if ($form->validate($vars)) {
    if ($vars->get('motd_id')) {
        Mottle::updateMOTD($vars->get('motd_id'),
                           $vars->get('motd_title'),
                           $vars->get('motd_post_time'),
                           $vars->get('motd_expire_time'),
                           $vars->get('motd_text'));
    } else {
        Mottle::addMOTD($vars->get('motd_title'),
                        $vars->get('motd_post_time'),
                        $vars->get('motd_expire_time'),
                        $vars->get('motd_text'));
    }

    header('Location: ' . Horde::applicationUrl('list.php', true));
    exit;
}

if ($vars->get('motd_id')) {
    $form->setTitle(_("Edit a message"));
    $form->setButtons(_("Update"), true);
} else {
    $form->setTitle(_("Insert a message"));
    $form->setButtons(_("Add"), true);
}

/* Render the page. */
$title = $form->getTitle();
require MOTTLE_TEMPLATES . '/common-header.inc';
require MOTTLE_TEMPLATES . '/menu.inc';
$form->renderActive(new Horde_Form_Renderer(), $vars, 'edit.php', 'post');
require $registry->get('templates', 'horde') . '/common-footer.inc';
