<?php
/**
 * Mottle base class.
 *
 * $Horde: mottle/lib/Mottle.php,v 1.17 2005-09-23 23:02:06 chuck Exp $
 *
 * @package Mottle
 */
class Mottle {

    function addMOTD($title, $post_time, $expire_time, $text)
    {
        global $notification;

        /* Create New Share */
        $motd = $GLOBALS['mottle_shares']->newShare(md5(microtime()));
        $motd->set('name', _("MOTD"));

        $motd->set('title', $title);
        $motd->set('post_time_month', $post_time['month']);
        $motd->set('post_time_day', $post_time['day']);
        $motd->set('post_time_year', $post_time['year']);
        $motd->set('expire_time_month', $expire_time['month']);
        $motd->set('expire_time_day', $expire_time['day']);
        $motd->set('expire_time_year', $expire_time['year']);
        $motd->set('text', $text);
        $result = $GLOBALS['mottle_shares']->addShare($motd);

        if (is_a($result, 'PEAR_Error')) {
            $notification->push(sprintf(_("The MOTD \"%s\" couldn't be added: %s"), $title, $result->getMessage()), 'horde.error');
        } else {
            $notification->push(sprintf(_("The MOTD \"%s\" has been added."), $title), 'horde.success');
        }
    }

    function updateMOTD($id, $title, $post_time, $expire_time, $text)
    {
        global $notification;

        $motd = &$GLOBALS['mottle_shares']->getShare($id);
        if (!is_a($motd, 'PEAR_Error') && $motd->hasPermission(Auth::getAuth(), PERMS_EDIT)) {
            $motd->set('title', $title);
            $motd->set('post_time_month', $post_time['month']);
            $motd->set('post_time_day', $post_time['day']);
            $motd->set('post_time_year', $post_time['year']);
            $motd->set('expire_time_month', $expire_time['month']);
            $motd->set('expire_time_day', $expire_time['day']);
            $motd->set('expire_time_year', $expire_time['year']);
            $motd->set('text', $text);
            $motd->save();

            $notification->push(sprintf(_("The MOTD \"%s\" has been updated."), $title), 'horde.success');
        } else {
            $notification->push(_("Access denied updating this MOTD."), 'horde.error');
        }
    }

    function deleteMOTD($id)
    {
        global $notification;

        $motd = $GLOBALS['mottle_shares']->getShare($id);
        if (!is_a($motd, 'PEAR_Error') && $motd->hasPermission(Auth::getAuth(), PERMS_DELETE)) {
            $title = $motd->get('title');
            $result = $GLOBALS['mottle_shares']->removeShare($motd);

            if (is_a($result, 'PEAR_Error')) {
                $notification->push(sprintf(_("Unable to delete \"%s\": %s"), $title, $result->getMessage()), 'horde.error');
            } else {
                $notification->push(sprintf(_("The MOTD \"%s\" has been deleted."), $title), 'horde.success');
            }
        } else {
            $notification->push(_("Access denied deleting this MOTD."), 'horde.error');
        }
    }

    function getMOTD($id)
    {
        $motd = &$GLOBALS['mottle_shares']->getShare($id);
        $post_time = array();
        $expire_time = array();
        $date_format = $GLOBALS['prefs']->getValue('date_format') ? $GLOBALS['prefs']->getValue('date_format') : '%x';

        /* Get the data for this MOTD. */
        $title = $motd->get('title');

        $post_time['month'] = $motd->get('post_time_month');
        $post_time['day'] = $motd->get('post_time_day');
        $post_time['year'] = $motd->get('post_time_year');
        $post_time['text'] = strftime($date_format, strtotime($motd->get('post_time_year') . '/' . $motd->get('post_time_month') . '/' . $motd->get('post_time_day')));

        $expire_time['month'] = $motd->get('expire_time_month');
        $expire_time['day'] = $motd->get('expire_time_day');
        $expire_time['year'] = $motd->get('expire_time_year');
        $expire_time['text'] = strftime($date_format, strtotime($motd->get('expire_time_year') . '/' . $motd->get('expire_time_month') . '/' . $motd->get('expire_time_day')));

        $text = $motd->get('text');

        return array('title' => $title,
                     'post_time' => $post_time,
                     'expire_time' => $expire_time,
                     'text' => $text);
    }

    function listMOTD($allMOTD = false, $owneronly = false, $permission = PERMS_SHOW)
    {
        $motds = $GLOBALS['mottle_shares']->listShares(Auth::getAuth(), $permission, $owneronly ? Auth::getAuth() : null);
        if (is_a($motds, 'PEAR_Error')) {
            Horde::logMessage($motds, __FILE__, __LINE__, PEAR_LOG_ERR);
            return array();
        } else {
            $motds = Mottle::removeExpiredMOTD($motds);

            if ($allMOTD == false) {
                $motds = Mottle::findCurrentsMOTD($motds);
            }

            return $motds;
        }
    }

    function listExpiredMOTD($allMOTD = false, $owneronly = false, $permission = PERMS_SHOW)
    {
        $motds = $GLOBALS['mottle_shares']->listShares(Auth::getAuth(), $permission, $owneronly ? Auth::getAuth() : null);
        if (is_a($motds, 'PEAR_Error')) {
            Horde::logMessage($motds, __FILE__, __LINE__, PEAR_LOG_ERR);
            return array();
        } else {
            foreach (array_keys($motds) as $i => $id) {
                if (preg_match('/^[A-Fa-f0-9]{32}$/',$id)) {
                    $expiration = strtotime($motds[$id]->get('expire_time_year') . '/' . $motds[$id]->get('expire_time_month') . '/' . $motds[$id]->get('expire_time_day'));
                    if ($expiration > time()) {
                        unset($motds[$id]);
                    }
                } else {
                    unset($motds[$id]);
                }
            }

            return $motds;
        }
    }

    function findCurrentsMOTD($motds)
    {
        foreach (array_keys($motds) as $i => $id) {
            if (preg_match('/^[A-Fa-f0-9]{32}$/',$id)) {
                $post_time = strtotime($motds[$id]->get('post_time_year') . '/' . $motds[$id]->get('post_time_month') . '/' . $motds[$id]->get('post_time_day'));
                if ($post_time > time()) {
                    unset($motds[$id]);
                }
            } else {
                unset($motds[$id]);
            }
        }

        return $motds;
    }

    function removeExpiredMOTD($motds)
    {
        global $conf;

        foreach (array_keys($motds) as $id) {
            if (preg_match('/^[A-Fa-f0-9]{32}$/',$id)) {
                $expiration = strtotime($motds[$id]->get('expire_time_year') . '/' . $motds[$id]->get('expire_time_month') . '/' . $motds[$id]->get('expire_time_day'));

                if ($expiration < time()) {
                    if ($conf['mottle']['remove_expired'] == true) {
                        $GLOBALS['mottle_shares']->removeShare($motds[$id]);
                    }
                    unset($motds[$id]);
                }
            } else {
                unset($motds[$id]);
            }
        }

        return $motds;
    }

    /**
     * Build Mottle's list of menu items.
     */
    function getMenu($returnType = 'object')
    {
        global $conf;

        require_once 'Horde/Menu.php';

        $menu = &new Menu(HORDE_MENU_MASK_ALL & ~HORDE_MENU_MASK_PREFS);
        $menu->add(Horde::applicationUrl('list.php'), _("MOTDs _List"), 'home.png');

        if ($conf['mottle']['remove_expired'] == false) {
            $menu->add(Horde::applicationUrl('archive.php'), _("_Archives"), 'archive.png');
        }

        /* Only Admins can add MOTDs. */
        if (Auth::isAdmin()) {
            $menu->add(Horde::applicationUrl('edit.php'), _("_New MOTD"), 'add.png');
        }

        if ($returnType == 'object') {
            return $menu;
        } else {
            return $menu->render();
        }
    }

}
